@@ -1,13 +1,11 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
-from suanpan.lazy_import import lazy_import
 from suanpan.utils import json
 
-np = lazy_import('numpy')
-
 
 def loadjson(obj, *args, **kwargs):  # pylint: disable=unused-argument
+    import numpy as np
     return np.frombuffer(obj["data"], obj["dtype"]).reshape(obj["shape"])
 
 
@@ -40,12 +38,14 @@ def dumpjsonf(npy, fp, *args, **kwargs):
 
 
 def load(file, *args, **kwargs):
+    import numpy as np
     kwargs.setdefault("allow_pickle", True)
     kwargs.setdefault("fix_imports", True)
     return np.load(file, *args, **kwargs)
 
 
 def dump(npy, file, *args, **kwargs):
+    import numpy as np
     kwargs.setdefault("allow_pickle", True)
     kwargs.setdefault("fix_imports", True)
     return np.save(file, npy, *args, **kwargs)
